<?php

if ( ! defined( 'ABSPATH' ) ) {
    exit; // disable direct access
}

if ( ! class_exists('Mega_Menu_Menu_Item_Manager') ) :

/**
 *
 * @since 1.4
 */
class Mega_Menu_Menu_Item_Manager {

    var $menu_id = 0;

	var $menu_item_id = 0;

    var $menu_item_depth = 0;

	var $menu_item_meta = array();


	/**
	 * Constructor
	 *
	 * @since 1.4
	 */
	public function __construct() {

		add_action( 'wp_ajax_mm_get_lightbox_html', array( $this, 'ajax_get_lightbox_html' ) );
		add_action( 'wp_ajax_mm_save_menu_item_settings', array( $this, 'ajax_save_menu_item_settings') );

        add_filter( 'megamenu_tabs', array( $this, 'add_mega_menu_tab'), 10, 5 );
        add_filter( 'megamenu_tabs', array( $this, 'add_general_settings_tab'), 10, 5 );
        add_filter( 'megamenu_tabs', array( $this, 'add_icon_tab'), 10, 5 );
        //add_filter( 'megamenu_tabs', array( $this, 'add_custom_styling_tab'), 10, 5 );
        //add_filter( 'megamenu_tabs', array( $this, 'add_roles_tab'), 10, 5 );
        //add_filter( 'megamenu_tabs', array( $this, 'add_replacements_tab'), 10, 5 );

	}

    /**
     * Return the HTML to display in the 'Styling' tab
     *
     * @since 1.7
     * @return array
     */
    public function add_custom_styling_tab( $tabs, $menu_item_id, $menu_id, $menu_item_depth, $menu_item_meta ) {

        if ( $this->nags_are_hidden() || is_plugin_active('megamenu-pro/megamenu-pro.php') ) {
            return $tabs;
        }

        $return = '<h4 class="first">' . __("Custom Item Styling", "megamenu") . '</h4>';
        $return .= "<p class='tab-description'>" . __("Customize the styling of this menu item only.", "megamenu_pro") . "</p>";
        $return .= "<p class='tab-description'>" . __("Set custom sub menu widths, font colors, font size, icon styling, sub menu background images and lots more.", "megamenu_pro") . "</p>";

        $return .= $this->get_pro_upgrade_text();

        $tabs['pro_custom_styling'] = array(
            'title' => __('Styling', 'megamenu'),
            'content' => $return
        );

        return $tabs;

    }

    /**
     * Return the HTML to display in the 'Roles' tab
     *
     * @since 2.2.3.2
     * @return array
     */
    public function add_roles_tab( $tabs, $menu_item_id, $menu_id, $menu_item_depth, $menu_item_meta ) {

        if ( $this->nags_are_hidden() || is_plugin_active('megamenu-pro/megamenu-pro.php') ) {
            return $tabs;
        }

        $return = '<h4 class="first">' . __("Roles & Restrictions", "megamenu") . '</h4>';
        $return .= "<p class='tab-description'>" . __("Restrict the display of this menu item to users with a specific role, or by logged in status.", "megamenu_pro") . "</p>";
        $return .= $this->get_pro_upgrade_text();

        $tabs['pro_roles'] = array(
            'title' => __('Roles', 'megamenu'),
            'content' => $return
        );

        return $tabs;

    }


    /**
     * Return the HTML to display in the 'Replacements' tab
     *
     * @since 2.2.3.2
     * @return array
     */
    public function add_replacements_tab( $tabs, $menu_item_id, $menu_id, $menu_item_depth, $menu_item_meta ) {

        if ( $this->nags_are_hidden() || is_plugin_active('megamenu-pro/megamenu-pro.php') ) {
            return $tabs;
        }

        $return  = '<h4 class="first">' . __("Replacements", "megamenu") . '</h4>';
        $return .= '<p class="tab-description">' . __("Replace this menu item with something else: a logo, a search box, WooCommerce cart total, Easy Digital Downloads cart total, custom HTML or a shortcode", "megamenu_pro") . "</p>";
        $return .= $this->get_pro_upgrade_text();


        $tabs['pro_replacements'] = array(
            'title' => __('Replacements', 'megamenu'),
            'content' => $return
        );

        return $tabs;

    }


    /**
     * Return the text for displaying go pro nag
     *
     * @since 2.2.3.2
     * @return string
     */
    private function get_pro_upgrade_text() {

        $return  = '<div class="in-pro">';
        $return .= "<p>This functionality is available in <a href='https://www.megamenu.com/upgrade/?utm_source=free&amp;utm_medium=lightbox&amp;utm_campaign=pro' target='_blank'>Max Mega Menu Pro</a><span class='dashicons dashicons-migrate'></span></p>";
        $return .= '<p><a class="hide-pro-nags">Hide this notice for 90 days</a></p>';
        $return .= '</div>';

        return $return;

    }


    /**
     * Returns true if nags have been hidden within the past 90 days
     * (I really wish I did not have to put in nags, but development and support is entirely funded
     * by upgrades)
     *
     * @since 2.2.3.2
     * @return bool
     */
    private function nags_are_hidden() {
        $transient = get_transient('megamenu_nag');

        if ( ! $transient ) {
            return false;
        }

        if ( strtotime("+90 days", $transient) > time() ) {
            return true;
        }

        return false;
    }


    /**
     * Set up the class
     *
     * @since 1.4
     */
    private function init() {

        if ( isset( $_POST['menu_item_id'] ) ) {

            $this->menu_item_id = absint( $_POST['menu_item_id'] );

            $saved_settings = array_filter( (array) get_post_meta( $this->menu_item_id, '_megamenu', true ) );

            $this->menu_item_meta = array_merge( Mega_Menu_Nav_Menus::get_menu_item_defaults(), $saved_settings );

        }

        if ( isset( $_POST['menu_item_depth'] ) ) {

            $this->menu_item_depth = absint( $_POST['menu_item_depth'] );

        }

        if ( isset( $_POST['menu_id'] ) ) {

            $this->menu_id = absint( $_POST['menu_id'] );

        }

    }


    /**
     * Save custom menu item fields.
     *
     * @since 1.4
     */
    public static function ajax_save_menu_item_settings() {

    	check_ajax_referer( 'megamenu_edit' );

        $submitted_settings = isset( $_POST['settings'] ) ? $_POST['settings'] : array();

        $menu_item_id = absint( $_POST['menu_item_id'] );

        if ( $menu_item_id > 0 && is_array( $submitted_settings ) ) {

            // only check the checkbox values if the general settings form was submitted
            if ( isset( $_POST['tab'] ) && $_POST['tab'] == 'general_settings' ) {

                // Hide Text checkbox is unchecked
                if ( ! isset( $submitted_settings['hide_text'] ) ) {

                    $submitted_settings['hide_text'] = 'false';

                }

                // Disable Link checkbox is unchecked
                if ( ! isset( $submitted_settings['disable_link'] ) ) {

                    $submitted_settings['disable_link'] = 'false';

                }

                // Disable arrow checkbox is unchecked
                if ( ! isset ( $submitted_settings['hide_arrow'] ) ) {

                    $submitted_settings['hide_arrow'] = 'false';

                }

                // Hide on mobile checkbox is unchecked
                if ( ! isset ( $submitted_settings['hide_on_mobile'] ) ) {

                    $submitted_settings['hide_on_mobile'] = 'false';

                }

                // Hide on mobile checkbox is unchecked
                if ( ! isset ( $submitted_settings['hide_sub_menu_on_mobile'] ) ) {

                    $submitted_settings['hide_sub_menu_on_mobile'] = 'false';

                }

                // Hide on desktop checkbox is unchecked
                if ( ! isset ( $submitted_settings['hide_on_desktop'] ) ) {

                    $submitted_settings['hide_on_desktop'] = 'false';

                }

            }

            $submitted_settings = apply_filters( "megamenu_menu_item_submitted_settings", $submitted_settings, $menu_item_id );

            $existing_settings = get_post_meta( $menu_item_id, '_megamenu', true);

        	if ( is_array( $existing_settings ) ) {

        		$submitted_settings = array_merge( $existing_settings, $submitted_settings );

        	}

        	update_post_meta( $menu_item_id, '_megamenu', $submitted_settings );

            do_action( "megamenu_save_menu_item_settings", $menu_item_id );

        }

        if ( isset( $_POST['clear_cache'] ) ) {

            do_action("megamenu_delete_cache");

        }

        if ( ob_get_contents() ) ob_clean(); // remove any warnings or output from other plugins which may corrupt the response

        wp_send_json_success();

    }


	/**
	 * Return the HTML to display in the Lightbox
     *
     * @since 1.4
     * @return string
	 */
	public function ajax_get_lightbox_html() {

		check_ajax_referer( 'megamenu_edit' );

        $this->init();

		$tabs = array();

        $tabs = apply_filters( "megamenu_tabs", $tabs, $this->menu_item_id, $this->menu_id, $this->menu_item_depth, $this->menu_item_meta );

        if ( ob_get_contents() ) ob_clean(); // remove any warnings or output from other plugins which may corrupt the response

		wp_send_json_success( json_encode( $tabs ) );
	}


	/**
	 * Return the HTML to display in the 'Mega Menu' tab
     *
     * @since 1.7
     * @return array
	 */
	public function add_mega_menu_tab( $tabs, $menu_item_id, $menu_id, $menu_item_depth, $menu_item_meta ) {

        if ( $menu_item_depth > 0 ) {
            $tabs['mega_menu'] = array(
                'title' => __('Sub Menu', 'megamenu'),
                'content' => '<em>' . __( "Mega Menus can only be created on top level menu items.", "megamenu" ) . '</em>'
            );

            return $tabs;
        }

		$widget_manager = new Mega_Menu_Widget_Manager();

		$all_widgets = $widget_manager->get_available_widgets();

        $submenu_options = apply_filters("megamenu_submenu_options", array(
            'flyout' => __("Flyout Menu", "megamenu"),
            'megamenu' => __("Mega Menu", "megamenu")
        ), $menu_item_meta);

        $return = "<label for='mm_enable_mega_menu'>" . __("Sub menu display mode", "megamenu") . "</label>";

        $return .= "<select id='mm_enable_mega_menu' name='settings[type]'>";

        foreach ( $submenu_options as $type => $label ) {
            $return .= "<option id='{$type}' value='{$type}' " . selected( $menu_item_meta['type'], $type, false ) . ">{$label}</option>";
        }
        $return .= "</select>";

        $return .= "<select id='mm_number_of_columns' name='settings[panel_columns]'>";
        $return .= "    <option value='1' " . selected( $menu_item_meta['panel_columns'], 1, false ) . ">1 " . __("column", "megamenu") . "</option>";
        $return .= "    <option value='2' " . selected( $menu_item_meta['panel_columns'], 2, false ) . ">2 " . __("columns", "megamenu") . "</option>";
        $return .= "    <option value='3' " . selected( $menu_item_meta['panel_columns'], 3, false ) . ">3 " . __("columns", "megamenu") . "</option>";
        $return .= "    <option value='4' " . selected( $menu_item_meta['panel_columns'], 4, false ) . ">4 " . __("columns", "megamenu") . "</option>";
        $return .= "    <option value='5' " . selected( $menu_item_meta['panel_columns'], 5, false ) . ">5 " . __("columns", "megamenu") . "</option>";
        $return .= "    <option value='6' " . selected( $menu_item_meta['panel_columns'], 6, false ) . ">6 " . __("columns", "megamenu") . "</option>";
        $return .= "    <option value='7' " . selected( $menu_item_meta['panel_columns'], 7, false ) . ">7 " . __("columns", "megamenu") . "</option>";
        $return .= "    <option value='8' " . selected( $menu_item_meta['panel_columns'], 8, false ) . ">8 " . __("columns", "megamenu") . "</option>";
        $return .= "    <option value='9' " . selected( $menu_item_meta['panel_columns'], 9, false ) . ">9 " . __("columns", "megamenu") . "</option>";
        $return .= "</select>";

        $return .= "<select id='mm_widget_selector'>";
        $return .= "    <option value='disabled'>" . __("Select a Widget to add to the panel", "megamenu") . "</option>";

        foreach ( $all_widgets as $widget ) {
            $return .= "<option value='" . $widget['value'] . "'>" . $widget['text'] . "</option>";
        }

        $return .= "</select>";

        $class = $menu_item_meta['type'] == 'megamenu' ? 'enabled' : 'disabled';

        $return .= "<div id='widgets' class='{$class}' data-columns='{$this->menu_item_meta['panel_columns']}'>";

        $items = $widget_manager->get_widgets_and_menu_items_for_menu_id( $menu_item_id, $this->menu_id );

        if ( count ( $items ) ) {

            foreach ( $items as $item ) {
                $return .= '<div class="widget" title="' . esc_attr( $item['title'] ) . '" id="' . esc_attr( $item['id'] ) . '" data-columns="' . esc_attr( $item['columns'] ) . '" data-type="' . esc_attr( $item['type'] ) . '" data-id="' . esc_attr( $item['id'] ) . '">';
                $return .= '    <div class="widget-top">';
                $return .= '        <div class="widget-title-action">';
                $return .= '            <a class="widget-option widget-contract" title="' . esc_attr( __("Contract", "megamenu") ) . '"></a>';
                $return .= '            <span class="widget-cols"><span class="widget-num-cols">' . $item['columns'] . '</span><span class="widget-of">/</span><span class="widget-total-cols">' . $menu_item_meta['panel_columns'] . '</span></span>';
                $return .= '            <a class="widget-option widget-expand" title="' . esc_attr( __("Expand", "megamenu") ) . '"></a>';
                $return .= '            <a class="widget-option widget-action" title="' . esc_attr( __("Edit", "megamenu") ) . '"></a>';
                $return .= '        </div>';
                $return .= '        <div class="widget-title">';
                $return .= '            <h4>' .  esc_html( $item['title'] ) . '</h4>';
                $return .= '        </div>';
                $return .= '    </div>';
                $return .= '    <div class="widget-inner"></div>';
                $return .= '</div>';
            }

        } else {
            $return .= "<p class='no_widgets'>" .  __("No widgets found. Add a widget to this area using the Widget Selector (top right)", "megamenu") . "</p>";
        }

        $return .= "</div>";

        $tabs['mega_menu'] = array(
            'title' => __('Mega Menu', 'megamenu'),
            'content' => $return
        );

        return $tabs;
	}


	/**
	 * Return the HTML to display in the 'General Settings' tab
     *
     * @since 1.7
     * @return array
	 */
	public function add_general_settings_tab( $tabs, $menu_item_id, $menu_id, $menu_item_depth, $menu_item_meta ) {

		$return  = '<form>';
        $return .= '    <input type="hidden" name="menu_item_id" value="' . $menu_item_id . '" />';
        $return .= '    <input type="hidden" name="action" value="mm_save_menu_item_settings" />';
        $return .= '    <input type="hidden" name="_wpnonce" value="' . wp_create_nonce('megamenu_edit') . '" />';
        $return .= '    <input type="hidden" name="tab" value="general_settings" />';
        $return .= '    <h4 class="first">' . __("Menu Item Settings", "megamenu") . '</h4>';
        $return .= '    <table>';
        $return .= '        <tr>';
        $return .= '            <td class="mega-name">';
        $return .=                  __("Hide Text", "megamenu");
        $return .= '            </td>';
        $return .= '            <td class="mega-value">';
        $return .= '                <input type="checkbox" name="settings[hide_text]" value="true" ' . checked( $menu_item_meta['hide_text'], 'true', false ) . ' />';
        $return .= '            </td>';
        $return .= '        </tr>';
        $return .= '        <tr>';
        $return .= '            <td class="mega-name">';
        $return .=                  __("Hide Arrow", "megamenu");
        $return .= '            </td>';
        $return .= '            <td class="mega-value">';
        $return .= '                <input type="checkbox" name="settings[hide_arrow]" value="true" ' . checked( $menu_item_meta['hide_arrow'], 'true', false ) . ' />';
        $return .= '            </td>';
        $return .= '        </tr>';
        $return .= '        <tr>';
        $return .= '            <td class="mega-name">';
        $return .=                  __("Disable Link", "megamenu");
        $return .= '            </td>';
        $return .= '            <td class="mega-value">';
        $return .= '                <input type="checkbox" name="settings[disable_link]" value="true" ' . checked( $menu_item_meta['disable_link'], 'true', false ) . ' />';
        $return .= '            </td>';
        $return .= '        </tr>';
        $return .= '        <tr>';
        $return .= '            <td class="mega-name">';
        $return .=                  __("Hide Item on Mobile", "megamenu");
        $return .= '            </td>';
        $return .= '            <td class="mega-value">';
        $return .= '                <input type="checkbox" name="settings[hide_on_mobile]" value="true" ' . checked( $menu_item_meta['hide_on_mobile'], 'true', false ) . ' />';
        $return .= '            </td>';
        $return .= '        </tr>';
        $return .= '        <tr>';
        $return .= '            <td class="mega-name">';
        $return .=                  __("Hide Item on Desktop", "megamenu");
        $return .= '            </td>';
        $return .= '            <td class="mega-value">';
        $return .= '                <input type="checkbox" name="settings[hide_on_desktop]" value="true" ' . checked( $menu_item_meta['hide_on_desktop'], 'true', false ) . ' />';
        $return .= '            </td>';
        $return .= '        </tr>';
        $return .= '        <tr class="mega-menu-item-align">';
        $return .= '            <td class="mega-name">';
        $return .=                  __("Menu Item Align", "megamenu");
        $return .= '            </td>';
        $return .= '            <td class="mega-value">';

        if ( $menu_item_depth == 0 ) {

            $item_align = $menu_item_meta['item_align'];

            $float_left_display = $item_align == 'float-left' ? 'block' : 'none';
            $left_display = $item_align == 'left' ? 'block' : 'none';
            $right_display = $item_align == 'right' ? 'block' : 'none';

            $return .= '            <select id="mega-item-align" name="settings[item_align]">';
            $return .= '                <option value="float-left" ' . selected( $menu_item_meta['item_align'], 'float-left', false ) . '>' . __("Left", "megamenu") . '</option>';
            $return .= '                <option value="left" ' . selected( $menu_item_meta['item_align'], 'left', false ) . '>' . __("Default", "megamenu") . '</option>';
            $return .= '                <option value="right" ' . selected( $menu_item_meta['item_align'], 'right', false ) . '>' . __("Right", "megamenu") . '</option>';
            $return .= '            </select>';
            $return .= '            <div class="mega-description">';
            $return .= "                    <div class='float-left' style='display:{$float_left_display}'></div>";
            $return .= "                    <div class='left' style='display:{$left_display}'>" . __("Item will be aligned based on the 'Menu Items Align' option set in the Theme Editor", "megamenu") . "</div>";
            $return .= "                    <div class='right' style='display:{$right_display}'>" . __("Right aligned items will appear in reverse order on the right hand side of the menu bar", "megamenu") . "</div>";
            $return .= '            </div>';
        } else {
            $return .= '<em>' . __("Option only available for top level menu items", "megamenu") . '</em>';
        }

        $return .= '            </td>';
        $return .= '        </tr>';
        $return .= '        <tr class="mega-menu-icon-position">';
        $return .= '            <td class="mega-name">';
        $return .=                  __("Icon Position", "megamenu");
        $return .= '            </td>';
        $return .= '            <td class="mega-value">';
        $return .= '            <select id="mega-item-align" name="settings[icon_position]">';
        $return .= '                <option value="left" ' . selected( $menu_item_meta['icon_position'], 'left', false ) . '>' . __("Left", "megamenu") . '</option>';
        $return .= '                <option value="top" ' . selected( $menu_item_meta['icon_position'], 'top', false ) . '>' . __("Top", "megamenu") . '</option>';
        $return .= '                <option value="right" ' . selected( $menu_item_meta['icon_position'], 'right', false ) . '>' . __("Right", "megamenu") . '</option>';
        $return .= '            </select>';

        $return .= '            </td>';
        $return .= '        </tr>';

        $return .= apply_filters("megamenu_after_menu_item_settings", "",  $tabs, $menu_item_id, $menu_id, $menu_item_depth, $menu_item_meta );

    	$return .= '    </table>';

        $return .= '    <h4>' . __("Sub Menu Settings", "megamenu") . '</h4>';

        $return .= '    <table>';
        $return .= '        <tr class="mega-sub-menu-align">';
        $return .= '            <td class="mega-name">';
        $return .=                  __("Sub Menu Align", "megamenu");
        $return .= '            </td>';
        $return .= '            <td class="mega-value">';

        if ( $menu_item_depth == 0 ) {
            $return .= '            <select name="settings[align]">';
            $return .= '                <option value="bottom-left" ' . selected( $menu_item_meta['align'], 'bottom-left', false ) . '>' . __("Left edge of Parent", "megamenu") . '</option>';
            $return .= '                <option value="bottom-right" ' . selected( $menu_item_meta['align'], 'bottom-right', false ) . '>' . __("Right edge of Parent", "megamenu") . '</option>';
            $return .= '            </select>';
            $return .= '            <div class="mega-description">';
            $return .=                 __("Right aligned flyout menus will expand to the left", "megamenu");
            $return .= '            </div>';
        } else {
            $return .= '<em>' . __("Option only available for top level menu items", "megamenu") . '</em>';
        }

        $return .= '            </td>';
        $return .= '        </tr>';
        $return .= '        <tr>';
        $return .= '            <td class="mega-name">';
        $return .=                  __("Hide Sub Menu on Mobile", "megamenu");
        $return .= '            </td>';
        $return .= '            <td class="mega-value">';
        $return .= '                <input type="checkbox" name="settings[hide_sub_menu_on_mobile]" value="true" ' . checked( $menu_item_meta['hide_sub_menu_on_mobile'], 'true', false ) . ' />';
        $return .= '            </td>';
        $return .= '        </tr>';

        $return .= apply_filters("megamenu_after_menu_item_submenu_settings", "",  $tabs, $menu_item_id, $menu_id, $menu_item_depth, $menu_item_meta );

        $return .= '    </table>';


        $return .=     get_submit_button();
        $return .= '</form>';

        $tabs['general_settings'] = array(
            'title' => __('Settings', 'megamenu'),
            'content' => $return
        );

        return $tabs;

	}


	/**
	 * Return the HTML to display in the 'menu icon' tab
     *
     * @since 1.7
     * @return array
	 */
	public function add_icon_tab( $tabs, $menu_item_id, $menu_id, $menu_item_depth, $menu_item_meta ) {

        $icon_tabs = array(
            'dashicons' => array(
                'title' => __("Dashicons", "megamenu"),
                'active' => ! isset( $menu_item_meta['icon'] ) || ( isset( $menu_item_meta['icon'] ) && substr( $menu_item_meta['icon'], 0, strlen("dash") ) === "dash" || $menu_item_meta['icon'] == 'disabled' ),
                'content' => $this->dashicon_selector()
            ),
            'fontawesome' => array(
                'title' => __("Font Awesome", "megamenu"),
                'active' => false,
                'content' => $this->awesome_selector()
            ),
			/*
            'genericons' => array(
                'title' => __("Genericons", "megamenu"),
                'active' => false,
                'content' => str_replace( "{link}", "<a target='_blank' href='https://www.megamenu.com/upgrade/?utm_source=free&amp;utm_medium=icon&amp;utm_campaign=pro'>" . __("Max Mega Menu Pro", "megamenu") . "</a>", __("Choose from over 100 genericons with {link}", "megamenu") )
            ),
            'custom' => array(
                'title' => __("Custom Icon", "megamenu"),
                'active' => false,
                'content' => str_replace( "{link}", "<a target='_blank' href='https://www.megamenu.com/upgrade/?utm_source=free&amp;utm_medium=icon&amp;utm_campaign=pro'>" . __("Max Mega Menu Pro", "megamenu") . "</a>", __("Select icons from your media library with {link}", "megamenu") )
            )
			*/
        );

        $icon_tabs = apply_filters( "megamenu_icon_tabs", $icon_tabs, $menu_item_id, $menu_id, $menu_item_depth, $menu_item_meta );

        $return = "<h4 class='first'>" . __("Menu Item Icon", "megamenu") . "</h4>";
        $return .= "<ul class='mm_tabs horizontal'>";

        foreach ( $icon_tabs as $id => $icon_tab ) {

            $active = $icon_tab['active'] || count( $icon_tabs ) === 1 ? "active" : "";

            $return .= "<li rel='mm_tab_{$id}' class='mm_tab_horizontal {$active}'>";
            $return .= esc_html( $icon_tab['title'] );
            $return .= "</li>";

        }

        $return .= "</ul>";

        $return .= "<input type='text' class='filter_icons' placeholder='" . __("Search", "megamenu") . "' /><div class='clear'></div>";

        foreach ($icon_tabs as $id => $icon_tab) {

            $display = $icon_tab['active'] ? "block" : "none";

            $return .= "<div class='mm_tab_{$id}' style='display: {$display}'>";
            $return .= "    <form class='icon_selector'>";
            $return .= "        <input type='hidden' name='_wpnonce' value='" . wp_create_nonce('megamenu_edit') . "' />";
            $return .= "        <input type='hidden' name='menu_item_id' value='{$menu_item_id}' />";
            $return .= "        <input type='hidden' name='action' value='mm_save_menu_item_settings' />";
            $return .=          $icon_tab['content'];
            $return .= "    </form>";
            $return .= "</div>";

        }

        $tabs['menu_icon'] = array(
            'title' => __('Icon', 'megamenu'),
            'content' => $return
        );

        return $tabs;

	}

    /**
     * Return the form to select a dashicon
     *
     * @since 1.5.2
     * @return string
     */
    private function dashicon_selector() {

        $return  = "<div class='disabled'><input id='disabled' class='radio' type='radio' rel='disabled' name='settings[icon]' value='disabled' " . checked( $this->menu_item_meta['icon'], 'disabled', false ) . " />";
        $return .= "<label for='disabled'></label></div>";

        foreach ( $this->all_icons() as $code => $class ) {

            $bits = explode( "-", $code );
            $code = "&#x" . $bits[1] . "";
            $type = $bits[0];

            $return .= "<div class='{$type}'>";
            $return .= "    <input class='radio' id='{$class}' type='radio' rel='{$code}' name='settings[icon]' value='{$class}' " . checked( $this->menu_item_meta['icon'], $class, false ) . " />";
            $return .= "    <label rel='{$code}' class='{$class}' for='{$class}'></label>";
            $return .= "</div>";

        }

        return $return;
    }


    /**
     * List of all available DashIcon classes.
     *
     * @since 1.0
     * @return array - Sorted list of icon classes
     */
    public function all_icons() {

        $icons = array(
            'dash-f333' => 'dashicons-menu',
            'dash-f319' => 'dashicons-admin-site',
            'dash-f226' => 'dashicons-dashboard',
            'dash-f109' => 'dashicons-admin-post',
            'dash-f104' => 'dashicons-admin-media',
            'dash-f103' => 'dashicons-admin-links',
            'dash-f105' => 'dashicons-admin-page',
            'dash-f101' => 'dashicons-admin-comments',
            'dash-f100' => 'dashicons-admin-appearance',
            'dash-f106' => 'dashicons-admin-plugins',
            'dash-f110' => 'dashicons-admin-users',
            'dash-f107' => 'dashicons-admin-tools',
            'dash-f108' => 'dashicons-admin-settings',
            'dash-f112' => 'dashicons-admin-network',
            'dash-f102' => 'dashicons-admin-home',
            'dash-f111' => 'dashicons-admin-generic',
            'dash-f148' => 'dashicons-admin-collapse',
            'dash-f536' => 'dashicons-filter',
            'dash-f540' => 'dashicons-admin-customizer',
            'dash-f541' => 'dashicons-admin-multisite',
            'dash-f119' => 'dashicons-welcome-write-blog',
            'dash-f133' => 'dashicons-welcome-add-page',
            'dash-f115' => 'dashicons-welcome-view-site',
            'dash-f116' => 'dashicons-welcome-widgets-menus',
            'dash-f117' => 'dashicons-welcome-comments',
            'dash-f118' => 'dashicons-welcome-learn-more',
            'dash-f123' => 'dashicons-format-aside',
            'dash-f128' => 'dashicons-format-image',
            'dash-f161' => 'dashicons-format-gallery',
            'dash-f126' => 'dashicons-format-video',
            'dash-f130' => 'dashicons-format-status',
            'dash-f122' => 'dashicons-format-quote',
            'dash-f125' => 'dashicons-format-chat',
            'dash-f127' => 'dashicons-format-audio',
            'dash-f306' => 'dashicons-camera',
            'dash-f232' => 'dashicons-images-alt',
            'dash-f233' => 'dashicons-images-alt2',
            'dash-f234' => 'dashicons-video-alt',
            'dash-f235' => 'dashicons-video-alt2',
            'dash-f236' => 'dashicons-video-alt3',
            'dash-f501' => 'dashicons-media-archive',
            'dash-f500' => 'dashicons-media-audio',
            'dash-f499' => 'dashicons-media-code',
            'dash-f498' => 'dashicons-media-default',
            'dash-f497' => 'dashicons-media-document',
            'dash-f496' => 'dashicons-media-interactive',
            'dash-f495' => 'dashicons-media-spreadsheet',
            'dash-f491' => 'dashicons-media-text',
            'dash-f490' => 'dashicons-media-video',
            'dash-f492' => 'dashicons-playlist-audio',
            'dash-f493' => 'dashicons-playlist-video',
            'dash-f522' => 'dashicons-controls-play',
            'dash-f523' => 'dashicons-controls-pause',
            'dash-f519' => 'dashicons-controls-forward',
            'dash-f517' => 'dashicons-controls-skipforward',
            'dash-f518' => 'dashicons-controls-back',
            'dash-f516' => 'dashicons-controls-skipback',
            'dash-f515' => 'dashicons-controls-repeat',
            'dash-f521' => 'dashicons-controls-volumeon',
            'dash-f520' => 'dashicons-controls-volumeoff',
            'dash-f165' => 'dashicons-image-crop',
            'dash-f531' => 'dashicons-image-rotate',
            'dash-f166' => 'dashicons-image-rotate-left',
            'dash-f167' => 'dashicons-image-rotate-right',
            'dash-f168' => 'dashicons-image-flip-vertical',
            'dash-f169' => 'dashicons-image-flip-horizontal',
            'dash-f533' => 'dashicons-image-filter',
            'dash-f171' => 'dashicons-undo',
            'dash-f172' => 'dashicons-redo',
            'dash-f200' => 'dashicons-editor-bold',
            'dash-f201' => 'dashicons-editor-italic',
            'dash-f203' => 'dashicons-editor-ul',
            'dash-f204' => 'dashicons-editor-ol',
            'dash-f205' => 'dashicons-editor-quote',
            'dash-f206' => 'dashicons-editor-alignleft',
            'dash-f207' => 'dashicons-editor-aligncenter',
            'dash-f208' => 'dashicons-editor-alignright',
            'dash-f209' => 'dashicons-editor-insertmore',
            'dash-f210' => 'dashicons-editor-spellcheck',
            'dash-f211' => 'dashicons-editor-expand',
            'dash-f506' => 'dashicons-editor-contract',
            'dash-f212' => 'dashicons-editor-kitchensink',
            'dash-f213' => 'dashicons-editor-underline',
            'dash-f214' => 'dashicons-editor-justify',
            'dash-f215' => 'dashicons-editor-textcolor',
            'dash-f216' => 'dashicons-editor-paste-word',
            'dash-f217' => 'dashicons-editor-paste-text',
            'dash-f218' => 'dashicons-editor-removeformatting',
            'dash-f219' => 'dashicons-editor-video',
            'dash-f220' => 'dashicons-editor-customchar',
            'dash-f221' => 'dashicons-editor-outdent',
            'dash-f222' => 'dashicons-editor-indent',
            'dash-f223' => 'dashicons-editor-help',
            'dash-f224' => 'dashicons-editor-strikethrough',
            'dash-f225' => 'dashicons-editor-unlink',
            'dash-f320' => 'dashicons-editor-rtl',
            'dash-f474' => 'dashicons-editor-break',
            'dash-f475' => 'dashicons-editor-code',
            'dash-f476' => 'dashicons-editor-paragraph',
            'dash-f535' => 'dashicons-editor-table',
            'dash-f135' => 'dashicons-align-left',
            'dash-f136' => 'dashicons-align-right',
            'dash-f134' => 'dashicons-align-center',
            'dash-f138' => 'dashicons-align-none',
            'dash-f160' => 'dashicons-lock',
            'dash-f528' => 'dashicons-unlock',
            'dash-f145' => 'dashicons-calendar',
            'dash-f508' => 'dashicons-calendar-alt',
            'dash-f177' => 'dashicons-visibility',
            'dash-f530' => 'dashicons-hidden',
            'dash-f173' => 'dashicons-post-status',
            'dash-f464' => 'dashicons-edit',
            'dash-f182' => 'dashicons-trash',
            'dash-f537' => 'dashicons-sticky',
            'dash-f504' => 'dashicons-external',
            'dash-f142' => 'dashicons-arrow-up',
            'dash-f140' => 'dashicons-arrow-down',
            'dash-f139' => 'dashicons-arrow-right',
            'dash-f141' => 'dashicons-arrow-left',
            'dash-f342' => 'dashicons-arrow-up-alt',
            'dash-f346' => 'dashicons-arrow-down-alt',
            'dash-f344' => 'dashicons-arrow-right-alt',
            'dash-f340' => 'dashicons-arrow-left-alt',
            'dash-f343' => 'dashicons-arrow-up-alt2',
            'dash-f347' => 'dashicons-arrow-down-alt2',
            'dash-f345' => 'dashicons-arrow-right-alt2',
            'dash-f341' => 'dashicons-arrow-left-alt2',
            'dash-f156' => 'dashicons-sort',
            'dash-f229' => 'dashicons-leftright',
            'dash-f503' => 'dashicons-randomize',
            'dash-f163' => 'dashicons-list-view',
            'dash-f164' => 'dashicons-exerpt-view',
            'dash-f509' => 'dashicons-grid-view',
            'dash-f237' => 'dashicons-share',
            'dash-f240' => 'dashicons-share-alt',
            'dash-f242' => 'dashicons-share-alt2',
            'dash-f301' => 'dashicons-twitter',
            'dash-f303' => 'dashicons-rss',
            'dash-f465' => 'dashicons-email',
            'dash-f466' => 'dashicons-email-alt',
            'dash-f304' => 'dashicons-facebook',
            'dash-f305' => 'dashicons-facebook-alt',
            'dash-f462' => 'dashicons-googleplus',
            'dash-f325' => 'dashicons-networking',
            'dash-f308' => 'dashicons-hammer',
            'dash-f309' => 'dashicons-art',
            'dash-f310' => 'dashicons-migrate',
            'dash-f311' => 'dashicons-performance',
            'dash-f483' => 'dashicons-universal-access',
            'dash-f507' => 'dashicons-universal-access-alt',
            'dash-f486' => 'dashicons-tickets',
            'dash-f484' => 'dashicons-nametag',
            'dash-f481' => 'dashicons-clipboard',
            'dash-f487' => 'dashicons-heart',
            'dash-f488' => 'dashicons-megaphone',
            'dash-f489' => 'dashicons-schedule',
            'dash-f120' => 'dashicons-wordpress',
            'dash-f324' => 'dashicons-wordpress-alt',
            'dash-f157' => 'dashicons-pressthis',
            'dash-f463' => 'dashicons-update',
            'dash-f180' => 'dashicons-screenoptions',
            'dash-f348' => 'dashicons-info',
            'dash-f174' => 'dashicons-cart',
            'dash-f175' => 'dashicons-feedback',
            'dash-f176' => 'dashicons-cloud',
            'dash-f326' => 'dashicons-translation',
            'dash-f323' => 'dashicons-tag',
            'dash-f318' => 'dashicons-category',
            'dash-f480' => 'dashicons-archive',
            'dash-f479' => 'dashicons-tagcloud',
            'dash-f478' => 'dashicons-text',
            'dash-f147' => 'dashicons-yes',
            'dash-f158' => 'dashicons-no',
            'dash-f335' => 'dashicons-no-alt',
            'dash-f132' => 'dashicons-plus',
            'dash-f502' => 'dashicons-plus-alt',
            'dash-f460' => 'dashicons-minus',
            'dash-f153' => 'dashicons-dismiss',
            'dash-f159' => 'dashicons-marker',
            'dash-f155' => 'dashicons-star-filled',
            'dash-f459' => 'dashicons-star-half',
            'dash-f154' => 'dashicons-star-empty',
            'dash-f227' => 'dashicons-flag',
            'dash-f534' => 'dashicons-warning',
            'dash-f230' => 'dashicons-location',
            'dash-f231' => 'dashicons-location-alt',
            'dash-f178' => 'dashicons-vault',
            'dash-f332' => 'dashicons-shield',
            'dash-f334' => 'dashicons-shield-alt',
            'dash-f468' => 'dashicons-sos',
            'dash-f179' => 'dashicons-search',
            'dash-f181' => 'dashicons-slides',
            'dash-f183' => 'dashicons-analytics',
            'dash-f184' => 'dashicons-chart-pie',
            'dash-f185' => 'dashicons-chart-bar',
            'dash-f238' => 'dashicons-chart-line',
            'dash-f239' => 'dashicons-chart-area',
            'dash-f307' => 'dashicons-groups',
            'dash-f338' => 'dashicons-businessman',
            'dash-f336' => 'dashicons-id',
            'dash-f337' => 'dashicons-id-alt',
            'dash-f312' => 'dashicons-products',
            'dash-f313' => 'dashicons-awards',
            'dash-f314' => 'dashicons-forms',
            'dash-f473' => 'dashicons-testimonial',
            'dash-f322' => 'dashicons-portfolio',
            'dash-f330' => 'dashicons-book',
            'dash-f331' => 'dashicons-book-alt',
            'dash-f316' => 'dashicons-download',
            'dash-f317' => 'dashicons-upload',
            'dash-f321' => 'dashicons-backup',
            'dash-f469' => 'dashicons-clock',
            'dash-f339' => 'dashicons-lightbulb',
            'dash-f482' => 'dashicons-microphone',
            'dash-f472' => 'dashicons-desktop',
            'dash-f471' => 'dashicons-tablet',
            'dash-f470' => 'dashicons-smartphone',
            'dash-f525' => 'dashicons-phone',
            'dash-f510' => 'dashicons-index-card',
            'dash-f511' => 'dashicons-carrot',
            'dash-f512' => 'dashicons-building',
            'dash-f513' => 'dashicons-store',
            'dash-f514' => 'dashicons-album',
            'dash-f527' => 'dashicons-palmtree',
            'dash-f524' => 'dashicons-tickets-alt',
            'dash-f526' => 'dashicons-money',
            'dash-f328' => 'dashicons-smiley',
            'dash-f529' => 'dashicons-thumbs-up',
            'dash-f542' => 'dashicons-thumbs-down',
            'dash-f538' => 'dashicons-layout'
        );

        $icons = apply_filters( "megamenu_dashicons", $icons );

        ksort( $icons );

        return $icons;
    }
/**********************************************************/
    private function awesome_selector() {

        $return  = "<div class='disabled'><input id='disabled' class='radio' type='radio' rel='disabled' name='settings[icon]' value='disabled' " . checked( $this->menu_item_meta['icon'], 'disabled', false ) . " />";
        $return .= "<label for='disabled'></label></div>";

        foreach ( $this->all_icons_awesome() as $code => $class ) {

            $bits = explode( "-", $code );
            $code = "&#x" . $bits[1] . "";
            $type = $bits[0];

            $return .= "<div class='fa'>";
            $return .= "    <input class='radio' id='{$class}' type='radio' rel='{$code}' name='settings[icon]' value='{$class}' " . checked( $this->menu_item_meta['icon'], $class, false ) . " />";
            $return .= "    <label rel='{$code}' class='{$class}' for='{$class}'></label>";
            $return .= "</div>";

        }

        return $return;
    }


    /**
     * List of all available DashIcon classes.
     *
     * @since 1.0
     * @return array - Sorted list of icon classes
     */
    public function all_icons_awesome() {

        $icons = array(
 'awesome-1  ' => 'fa fa-address-book' , 
 'awesome-2  ' => 'fa fa-address-book-o' , 
 'awesome-3  ' => 'fa fa-address-card ', 
 'awesome-4  ' => 'fa fa-address-card-o ', 
 'awesome-5  ' => 'fa fa-bandcamp ', 
 'awesome-6  ' => 'fa fa-bath ', 
 'awesome-7  ' => 'fa fa-bathtub ', 
 'awesome-8  ' => 'fa fa-drivers-license' , 
 'awesome-9  ' => 'fa fa-drivers-license-o ', 
 'awesome-10 '=>  'fa fa-eercast' , 
 'awesome-11 '=>  'fa fa-envelope-open ', 
 'awesome-12 '=>  'fa fa-envelope-open-o' , 
 'awesome-13 '=>  'fa fa-etsy ', 
 'awesome-14 '=>  'fa fa-free-code-camp ', 
 'awesome-15 '=>  'fa fa-grav ', 
 'awesome-16 '=>  'fa fa-handshake-o ', 
 'awesome-17 '=>  'fa fa-id-badge' , 
 'awesome-18 '=>  'fa fa-id-card' , 
 'awesome-19 '=>  'fa fa-id-card-o' , 
 'awesome-20 '=>  'fa fa-imdb' , 
 'awesome-21 '=>  'fa fa-linode' , 
 'awesome-22 '=>  'fa fa-meetup' , 
 'awesome-23 '=>  'fa fa-microchip' , 
 'awesome-24 '=>  'fa fa-podcast' , 
 'awesome-25 '=>  'fa fa-quora' , 
 'awesome-26 '=>  'fa fa-ravelry' , 
 'awesome-27 '=>  'fa fa-s15' , 
 'awesome-28 '=>  'fa fa-shower ', 
 'awesome-29 '=>  'fa fa-snowflake-o ', 
 'awesome-30 '=>  'fa fa-superpowers ', 
 'awesome-31 '=>  'fa fa-telegram' , 
 'awesome-32 '=>  'fa fa-thermometer ', 
 'awesome-33 '=>  'fa fa-thermometer-0 ', 
 'awesome-34 '=>  'fa fa-thermometer-1 ', 
 'awesome-35 '=>  'fa fa-thermometer-2' , 
 'awesome-36 '=>  'fa fa-thermometer-3 ', 
 'awesome-37 '=>  'fa fa-thermometer-4 ', 
 'awesome-38 '=>  'fa fa-thermometer-empty ', 
 'awesome-39 '=>  'fa fa-thermometer-full ', 
 'awesome-40 '=>  'fa fa-thermometer-half ', 
 'awesome-41 '=>  'fa fa-thermometer-quarter ', 
 'awesome-42 '=>  'fa fa-thermometer-three-quarters ', 
 'awesome-43 '=>  'fa fa-times-rectangle ', 
 'awesome-44 '=>  'fa fa-times-rectangle-o ', 
 'awesome-45 '=>  'fa fa-user-circle ', 
 'awesome-46 '=>  'fa fa-user-circle-o ', 
 'awesome-47 '=>  'fa fa-user-o ', 
 'awesome-48 '=>  'fa fa-vcard ', 
 'awesome-49 '=>  'fa fa-vcard-o ', 
 'awesome-50 '=>  'fa fa-window-close ', 
 'awesome-51 '=>  'fa fa-window-close-o ', 
 'awesome-52 '=>  'fa fa-window-maximize ', 
 'awesome-53 '=>  'fa fa-window-minimize ', 
 'awesome-54 '=>  'fa fa-window-restore ', 
 'awesome-55 '=>  'fa fa-wpexplorer ', 
 'awesome-56 '=>  'fa fa-address-book ', 
 'awesome-57 '=>  'fa fa-address-book-o ', 
 'awesome-58 '=>  'fa fa-address-card ', 
 'awesome-59 '=>  'fa fa-address-card-o ', 
 'awesome-60 '=>  'fa fa-adjust ', 
 'awesome-61 '=>  'fa fa-american-sign-language-interpreting ', 
 'awesome-62 '=>  'fa fa-anchor ', 
 'awesome-63 '=>  'fa fa-archive ', 
 'awesome-64 '=>  'fa fa-area-chart ', 
 'awesome-65 '=>  'fa fa-arrows ', 
 'awesome-66 '=>  'fa fa-arrows-h', 
 'awesome-67 '=>  'fa fa-arrows-v ', 
 'awesome-68 '=>  'fa fa-asl-interpreting ', 
 'awesome-69 '=>  'fa fa-assistive-listening-systems ', 
 'awesome-70 '=>  'fa fa-asterisk ', 
 'awesome-71 '=>  'fa fa-at ', 
 'awesome-72 '=>  'fa fa-audio-description ', 
 'awesome-73 '=>  'fa fa-automobile ', 
 'awesome-74 '=>  'fa fa-balance-scale ', 
 'awesome-75 '=>  'fa fa-ban ', 
 'awesome-76 '=>  'fa fa-bank ', 
 'awesome-77 '=>  'fa fa-bar-chart ', 
 'awesome-78 '=>  'fa fa-bar-chart-o ', 
 'awesome-79 '=>  'fa fa-barcode ', 
 'awesome-80 '=>  'fa fa-bars ', 
 'awesome-81 '=>  'fa fa-bath ', 
 'awesome-82 '=>  'fa fa-bathtub ', 
 'awesome-83 '=>  'fa fa-battery ', 
 'awesome-84 '=>  'fa fa-battery-0 ', 
 'awesome-85 '=>  'fa fa-battery-1 ', 
 'awesome-86 '=>  'fa fa-battery-2 ', 
 'awesome-87 '=>  'fa fa-battery-3 ', 
 'awesome-88 '=>  'fa fa-battery-4 ', 
 'awesome-89 '=>  'fa fa-battery-empty ', 
 'awesome-90 '=>  'fa fa-battery-full ', 
 'awesome-91 '=>  'fa fa-battery-half ', 
 'awesome-92 '=>  'fa fa-battery-quarter ', 
 'awesome-93 '=>  'fa fa-battery-three-quarters ', 
 'awesome-94 '=>  'fa fa-bed ', 
 'awesome-95 '=>  'fa fa-beer ', 
 'awesome-96 '=>  'fa fa-bell ', 
 'awesome-97 '=>  'fa fa-bell-o ', 
 'awesome-98 '=>  'fa fa-bell-slash ', 
 'awesome-99 '=>  'fa fa-bell-slash-o ', 
 'awesome-100' => ' fa fa-bicycle ', 
 'awesome-101' => ' fa fa-binoculars ', 
 'awesome-102' => ' fa fa-birthday-cake ', 
 'awesome-103' => ' fa fa-blind ', 
 'awesome-104' => ' fa fa-bluetooth ', 
 'awesome-105' => ' fa fa-bluetooth-b ', 
 'awesome-106' => ' fa fa-bolt ', 
 'awesome-107' => ' fa fa-bomb ', 
 'awesome-108' => ' fa fa-book ', 
 'awesome-109' => ' fa fa-bookmark ', 
 'awesome-110' => ' fa fa-bookmark-o ', 
 'awesome-111' => ' fa fa-braille ', 
 'awesome-112' => ' fa fa-briefcase ', 
 'awesome-113' => ' fa fa-bug ', 
 'awesome-114' => ' fa fa-building ', 
 'awesome-115' => ' fa fa-building-o ', 
 'awesome-116' => ' fa fa-bullhorn ', 
 'awesome-117' => ' fa fa-bullseye ', 
 'awesome-118' => ' fa fa-bus ', 
 'awesome-119' => ' fa fa-cab ', 
 'awesome-120' => ' fa fa-calculator ', 
 'awesome-121' => ' fa fa-calendar ', 
 'awesome-122' => ' fa fa-calendar-check-o ', 
 'awesome-123' => ' fa fa-calendar-minus-o ', 
 'awesome-124' => ' fa fa-calendar-o ', 
 'awesome-125' => ' fa fa-calendar-plus-o ', 
 'awesome-126' => ' fa fa-calendar-times-o ', 
 'awesome-127' => ' fa fa-camera ', 
 'awesome-128' => ' fa fa-camera-retro ', 
 'awesome-129' => ' fa fa-car ', 
 'awesome-130' => ' fa fa-caret-square-o-down ', 
 'awesome-131' => ' fa fa-caret-square-o-left ', 
 'awesome-132' => ' fa fa-caret-square-o-right ', 
 'awesome-133' => ' fa fa-caret-square-o-up ', 
 'awesome-134' => ' fa fa-cart-arrow-down ', 
 'awesome-135' => ' fa fa-cart-plus ', 
 'awesome-136' => ' fa fa-cc' , 
 'awesome-137' => ' fa fa-certificate ', 
 'awesome-138' => ' fa fa-check ', 
 'awesome-139' => ' fa fa-check-circle' , 
 'awesome-140' => ' fa fa-check-circle-o ', 
 'awesome-141' => ' fa fa-check-square' , 
 'awesome-142' => ' fa fa-check-square-o ', 
 'awesome-143' => ' fa fa-child ', 
 'awesome-144' => ' fa fa-circle ', 
 'awesome-145' => ' fa fa-circle-o' , 
 'awesome-146' => ' fa fa-circle-o-notch ', 
 'awesome-147' => ' fa fa-circle-thin' , 
 'awesome-148' => ' fa fa-clock-o' , 
 'awesome-149' => ' fa fa-clone ', 
 'awesome-150' => ' fa fa-close ', 
 'awesome-151' => ' fa fa-cloud ', 
 'awesome-152' => ' fa fa-cloud-download ', 
 'awesome-153' => ' fa fa-cloud-upload ', 
 'awesome-154' => ' fa fa-code ', 
 'awesome-155' => ' fa fa-code-fork ', 
 'awesome-156' => ' fa fa-coffee ', 
 'awesome-157' => ' fa fa-cog ', 
 'awesome-158' => ' fa fa-cogs ', 
 'awesome-159' => ' fa fa-comment' , 
 'awesome-160' => ' fa fa-comment-o ', 
 'awesome-161' => ' fa fa-commenting ', 
 'awesome-162' => ' fa fa-commenting-o ', 
 'awesome-163' => ' fa fa-comments ', 
 'awesome-164' => ' fa fa-comments-o ', 
 'awesome-165' => ' fa fa-compass ', 
 'awesome-166' => ' fa fa-copyright ', 
 'awesome-167' => ' fa fa-creative-commons ', 
 'awesome-168' => ' fa fa-credit-card ', 
 'awesome-169' => ' fa fa-credit-card-alt' , 
 'awesome-170' => ' fa fa-crop' , 
 'awesome-171' => ' fa fa-crosshairs ', 
 'awesome-172' => ' fa fa-cube' , 
 'awesome-173' => ' fa fa-cubes' , 
 'awesome-174' => ' fa fa-cutlery ', 
 'awesome-175' => ' fa fa-dashboard' , 
 'awesome-176' => ' fa fa-database ', 
 'awesome-177' => ' fa fa-deaf ', 
 'awesome-178' => ' fa fa-deafness ', 
 'awesome-179' => ' fa fa-desktop' , 
 'awesome-180' => ' fa fa-diamond ', 
 'awesome-181' => ' fa fa-dot-circle-o ', 
 'awesome-182' => ' fa fa-download ', 
 'awesome-183' => ' fa fa-drivers-license ', 
 'awesome-184' => ' fa fa-drivers-license-o ', 
 'awesome-185' => ' fa fa-edit ', 
 'awesome-186' => ' fa fa-ellipsis-h ', 
 'awesome-187' => ' fa fa-ellipsis-v ', 
 'awesome-188' => ' fa fa-envelope ', 
 'awesome-189' => ' fa fa-envelope-o ', 
 'awesome-190' => ' fa fa-envelope-open ', 
 'awesome-191' => ' fa fa-envelope-open-o ', 
 'awesome-192' => ' fa fa-envelope-square ', 
 'awesome-193' => ' fa fa-eraser ', 
 'awesome-194' => ' fa fa-exchange ', 
 'awesome-195' => ' fa fa-exclamation ', 
 'awesome-196' => ' fa fa-exclamation-circle ', 
 'awesome-197' => ' fa fa-exclamation-triangle ', 
 'awesome-198' => ' fa fa-external-link' , 
 'awesome-199' => ' fa fa-external-link-square ', 
 'awesome-200' => ' fa fa-eye ', 
 'awesome-201' => ' fa fa-eye-slash', 
 'awesome-202' => ' fa fa-eyedropper ', 
 'awesome-203' => ' fa fa-fax' , 
 'awesome-204' => ' fa fa-feed ', 
 'awesome-205' => ' fa fa-female ', 
 'awesome-206' => ' fa fa-fighter-jet ', 
 'awesome-207' => ' fa fa-file-archive-o' , 
 'awesome-208' => ' fa fa-file-audio-o ', 
 'awesome-209' => ' fa fa-file-code-o ', 
 'awesome-210' => ' fa fa-file-excel-o ', 
 'awesome-211' => ' fa fa-file-image-o ', 
 'awesome-212' => ' fa fa-file-movie-o ', 
 'awesome-213' => ' fa fa-file-pdf-o ', 
 'awesome-214' => ' fa fa-file-photo-o ', 
 'awesome-215' => ' fa fa-file-picture-o ', 
 'awesome-216' => ' fa fa-file-powerpoint-o', 
 'awesome-217' => ' fa fa-file-sound-o ', 
 'awesome-218' => ' fa fa-file-video-o ', 
 'awesome-219' => ' fa fa-file-word-o' , 
 'awesome-220' => ' fa fa-file-zip-o ', 
 'awesome-221' => ' fa fa-film ', 
 'awesome-222' => ' fa fa-filter ', 
 'awesome-223' => ' fa fa-fire ', 
 'awesome-224' => ' fa fa-fire-extinguisher ', 
 'awesome-225' => ' fa fa-flag ', 
 'awesome-226' => ' fa fa-flag-checkered ', 
 'awesome-227' => ' fa fa-flag-o ', 
 'awesome-228' => ' fa fa-flash ', 
 'awesome-229' => ' fa fa-flask ', 
 'awesome-230' => ' fa fa-folder ', 
 'awesome-231' => ' fa fa-folder-o ', 
 'awesome-232' => ' fa fa-folder-open ', 
 'awesome-233' => ' fa fa-folder-open-o ', 
 'awesome-234' => ' fa fa-frown-o' , 
 'awesome-235' => ' fa fa-futbol-o ', 
 'awesome-236' => ' fa fa-gamepad ', 
 'awesome-237' => ' fa fa-gavel ', 
 'awesome-238' => ' fa fa-gear ', 
 'awesome-239' => ' fa fa-gears' , 
 'awesome-240' => ' fa fa-gift' , 
 'awesome-241' => ' fa fa-glass ', 
 'awesome-242' => ' fa fa-globe ', 
 'awesome-243' => ' fa fa-graduation-cap ', 
 'awesome-244' => ' fa fa-group' , 
 'awesome-245' => ' fa fa-hand-grab-o ', 
 'awesome-246' => ' fa fa-hand-lizard-o ', 
 'awesome-247' => ' fa fa-hand-paper-o' , 
 'awesome-248' => ' fa fa-hand-peace-o ', 
 'awesome-249' => ' fa fa-hand-pointer-o ', 
 'awesome-250' => ' fa fa-hand-rock-o' , 
 'awesome-251' => ' fa fa-hand-scissors-o ', 
 'awesome-252' => ' fa fa-hand-spock-o ', 
 'awesome-253' => ' fa fa-hand-stop-o ', 
 'awesome-254' => ' fa fa-handshake-o' , 
 'awesome-255' => ' fa fa-hard-of-hearing' , 
 'awesome-256' => ' fa fa-hashtag' , 
 'awesome-257' => ' fa fa-hdd-o' , 
 'awesome-258' => ' fa fa-headphones ', 
 'awesome-259' => ' fa fa-heart ', 
 'awesome-260' => ' fa fa-heart-o ', 
 'awesome-261' => ' fa fa-heartbeat ', 
 'awesome-262' => ' fa fa-history ', 
 'awesome-263' => ' fa fa-home ', 
 'awesome-264' => ' fa fa-hotel ', 
 'awesome-265' => ' fa fa-hourglass ', 
 'awesome-266' => ' fa fa-hourglass-1 ', 
 'awesome-267' => ' fa fa-hourglass-2 ', 
 'awesome-268' => ' fa fa-hourglass-3' , 
 'awesome-269' => ' fa fa-hourglass-end ', 
 'awesome-270' => ' fa fa-hourglass-half ', 
 'awesome-271' => ' fa fa-hourglass-o ', 
 'awesome-272' => ' fa fa-hourglass-start' , 
 'awesome-273' => ' fa fa-i-cursor ', 
 'awesome-274' => ' fa fa-id-badge ', 
 'awesome-275' => ' fa fa-id-card ', 
 'awesome-276' => ' fa fa-id-card-o ', 
 'awesome-277' => ' fa fa-image ', 
 'awesome-278' => ' fa fa-inbox ', 
 'awesome-279' => ' fa fa-industry ', 
 'awesome-280' => ' fa fa-info ', 
 'awesome-281' => ' fa fa-info-circle ', 
 'awesome-282' => ' fa fa-institution ', 
 'awesome-283' => ' fa fa-key' , 
 'awesome-284' => ' fa fa-keyboard-o ', 
 'awesome-285' => ' fa fa-language' , 
 'awesome-286' => ' fa fa-laptop ', 
 'awesome-287' => ' fa fa-leaf ', 
 'awesome-288' => ' fa fa-legal ', 
 'awesome-289' => ' fa fa-lemon-o ', 
 'awesome-290' => ' fa fa-level-down ', 
 'awesome-291' => ' fa fa-level-up ', 
 'awesome-292' => ' fa fa-life-bouy ', 
 'awesome-293' => ' fa fa-life-buoy ', 
 'awesome-294' => ' fa fa-life-ring ', 
 'awesome-295' => ' fa fa-life-saver ', 
 'awesome-296' => ' fa fa-lightbulb-o ', 
 'awesome-297' => ' fa fa-line-chart ', 
 'awesome-298' => ' fa fa-location-arrow ', 
 'awesome-299' => ' fa fa-lock' , 
 'awesome-300' => ' fa fa-low-vision' , 
 'awesome-301' => ' fa fa-magic ', 
 'awesome-302' => ' fa fa-magnet ', 
 'awesome-303' => ' fa fa-mail-forward ', 
 'awesome-304' => ' fa fa-mail-reply' , 
 'awesome-305' => ' fa fa-mail-reply-all ', 
 'awesome-306' => ' fa fa-male' , 
 'awesome-307' => ' fa fa-map' , 
 'awesome-308' => ' fa fa-map-marker' , 
 'awesome-309' => ' fa fa-map-o' , 
 'awesome-310' => ' fa fa-map-pin' , 
 'awesome-311' => ' fa fa-map-signs ', 
 'awesome-312' => ' fa fa-meh-o' , 
 'awesome-313' => ' fa fa-microchip' , 
 'awesome-314' => ' fa fa-microphone ', 
 'awesome-315' => ' fa fa-microphone-slash' , 
 'awesome-316' => ' fa fa-minus' , 
 'awesome-317' => ' fa fa-minus-circle ', 
 'awesome-318' => ' fa fa-minus-square ', 
 'awesome-319' => ' fa fa-minus-square-o ', 
 'awesome-320' => ' fa fa-mobile', 
 'awesome-321' => ' fa fa-mobile-phone ', 
 'awesome-322' => ' fa fa-money', 
 'awesome-323' => ' fa fa-moon-o ', 
 'awesome-324' => ' fa fa-mortar-board' , 
 'awesome-325' => ' fa fa-motorcycle ', 
 'awesome-326' => ' fa fa-mouse-pointer ', 
 'awesome-327' => ' fa fa-music ', 
 'awesome-328' => ' fa fa-navicon ', 
 'awesome-329' => ' fa fa-newspaper-o' , 
 'awesome-330' => ' fa fa-object-group' , 
 'awesome-331' => ' fa fa-object-ungroup' , 
 'awesome-332' => ' fa fa-paint-brush ', 
 'awesome-333' => ' fa fa-paper-plane ', 
 'awesome-334' => ' fa fa-paper-plane-o ', 
 'awesome-335' => ' fa fa-paw' , 
 'awesome-336' => ' fa fa-pencil ', 
 'awesome-337' => ' fa fa-pencil-square ', 
 'awesome-338' => ' fa fa-pencil-square-o ', 
 'awesome-339' => ' fa fa-percent ', 
 'awesome-340' => ' fa fa-phone ', 
 'awesome-341' => ' fa fa-phone-square ', 
 'awesome-342' => ' fa fa-photo ', 
 'awesome-343' => ' fa fa-picture-o ', 
 'awesome-344' => ' fa fa-pie-chart ', 
 'awesome-345' => ' fa fa-plane ', 
 'awesome-346' => ' fa fa-plug ', 
 'awesome-347' => ' fa fa-plus ', 
 'awesome-348' => ' fa fa-plus-circle ', 
 'awesome-349' => ' fa fa-plus-square ', 
 'awesome-350' => ' fa fa-plus-square-o ', 
 'awesome-351' => ' fa fa-podcast' , 
 'awesome-352' => ' fa fa-power-off ', 
 'awesome-353' => ' fa fa-print ', 
 'awesome-354' => ' fa fa-puzzle-piece ', 
 'awesome-355' => ' fa fa-qrcode ', 
 'awesome-356' => ' fa fa-question' , 
 'awesome-357' => ' fa fa-question-circle ', 
 'awesome-358' => ' fa fa-question-circle-o ', 
 'awesome-359' => ' fa fa-quote-left', 
 'awesome-360' => ' fa fa-quote-right ', 
 'awesome-361' => ' fa fa-random ', 
 'awesome-362' => ' fa fa-recycle ', 
 'awesome-363' => ' fa fa-refresh ', 
 'awesome-364' => ' fa fa-registered' , 
 'awesome-365' => ' fa fa-remove ', 
 'awesome-366' => ' fa fa-reorder ', 
 'awesome-367' => ' fa fa-reply ', 
 'awesome-368' => ' fa fa-reply-all ', 
 'awesome-369' => ' fa fa-retweet ', 
 'awesome-370' => ' fa fa-road ', 
 'awesome-371' => ' fa fa-rocket ', 
 'awesome-372' => ' fa fa-rss ', 
 'awesome-373' => ' fa fa-rss-square ', 
 'awesome-374' => ' fa fa-s15 ', 
 'awesome-375' => ' fa fa-search ', 
 'awesome-376' => ' fa fa-search-minus ', 
 'awesome-377' => ' fa fa-search-plus ', 
 'awesome-378' => ' fa fa-send ', 
 'awesome-379' => ' fa fa-send-o ', 
 'awesome-380' => ' fa fa-server ', 
 'awesome-381' => ' fa fa-share ', 
 'awesome-382' => ' fa fa-share-alt ', 
 'awesome-383' => ' fa fa-share-alt-square ', 
 'awesome-384' => ' fa fa-share-square ', 
 'awesome-385' => ' fa fa-share-square-o ', 
 'awesome-386' => ' fa fa-shield ', 
 'awesome-387' => ' fa fa-ship' , 
 'awesome-388' => ' fa fa-shopping-bag ', 
 'awesome-389' => ' fa fa-shopping-basket ', 
 'awesome-390' => ' fa fa-shopping-cart ', 
 'awesome-391' => ' fa fa-shower' , 
 'awesome-392' => ' fa fa-sign-in ', 
 'awesome-393' => ' fa fa-sign-language ', 
 'awesome-394' => ' fa fa-sign-out ', 
 'awesome-395' => ' fa fa-signal ', 
 'awesome-396' => ' fa fa-signing ', 
 'awesome-397' => ' fa fa-sitemap ', 
 'awesome-398' => ' fa fa-sliders ', 
 'awesome-399' => ' fa fa-smile-o ', 
 'awesome-400' => ' fa fa-snowflake-o ', 
 'awesome-401' => ' fa fa-soccer-ball-o ', 
 'awesome-402' => ' fa fa-sort ', 
 'awesome-403' => ' fa fa-sort-alpha-asc ', 
 'awesome-404' => ' fa fa-sort-alpha-desc' , 
 'awesome-405' => ' fa fa-sort-amount-asc' , 
 'awesome-406' => ' fa fa-sort-amount-desc ', 
 'awesome-407' => ' fa fa-sort-asc ', 
 'awesome-408' => ' fa fa-sort-desc ', 
 'awesome-409' => ' fa fa-sort-down ', 
 'awesome-410' => ' fa fa-sort-numeric-asc ', 
 'awesome-411' => ' fa fa-sort-numeric-desc ', 
 'awesome-412' => ' fa fa-sort-up ', 
 'awesome-413' => ' fa fa-space-shuttle' , 
 'awesome-414' => ' fa fa-spinner' , 
 'awesome-415' => ' fa fa-spoon ', 
 'awesome-416' => ' fa fa-square ', 
 'awesome-417' => ' fa fa-square-o' , 
 'awesome-418' => ' fa fa-star ', 
 'awesome-419' => ' fa fa-star-half ', 
 'awesome-420' => ' fa fa-star-half-empty ', 
 'awesome-421' => ' fa fa-star-half-full ', 
 'awesome-422' => ' fa fa-star-half-o ', 
 'awesome-423' => ' fa fa-star-o ', 
 'awesome-424' => ' fa fa-sticky-note ', 
 'awesome-425' => ' fa fa-sticky-note-o' , 
 'awesome-426' => ' fa fa-street-view ', 
 'awesome-427' => ' fa fa-suitcase' , 
 'awesome-428' => ' fa fa-sun-o ', 
 'awesome-429' => ' fa fa-support ', 
 'awesome-430' => ' fa fa-tablet' , 
 'awesome-431' => ' fa fa-tachometer ', 
 'awesome-432' => ' fa fa-tag' , 
 'awesome-433' => ' fa fa-tags ', 
 'awesome-434' => ' fa fa-tasks ', 
 'awesome-435' => ' fa fa-taxi ', 
 'awesome-436' => ' fa fa-television ', 
 'awesome-437' => ' fa fa-terminal ', 
 'awesome-438' => ' fa fa-thermometer ', 
 'awesome-439' => ' fa fa-thermometer-0 ', 
 'awesome-440' => ' fa fa-thermometer-1 ', 
 'awesome-441' => ' fa fa-thermometer-2 ', 
 'awesome-442' => ' fa fa-thermometer-3 ', 
 'awesome-443' => ' fa fa-thermometer-4' , 
 'awesome-444' => ' fa fa-thermometer-empty ', 
 'awesome-445' => ' fa fa-thermometer-full ', 
 'awesome-446' => ' fa fa-thermometer-half ', 
 'awesome-447' => ' fa fa-thermometer-quarter ', 
 'awesome-448' => ' fa fa-thermometer-three-quarters ', 
 'awesome-449' => ' fa fa-thumb-tack ', 
 'awesome-450' => ' fa fa-thumbs-down ', 
 'awesome-451' => ' fa fa-thumbs-o-down' , 
 'awesome-452' => ' fa fa-thumbs-o-up ', 
 'awesome-453' => ' fa fa-thumbs-up ', 
 'awesome-454' => ' fa fa-ticket' , 
 'awesome-455' => ' fa fa-times ', 
 'awesome-456' => ' fa fa-times-circle' , 
 'awesome-457' => ' fa fa-times-circle-o ', 
 'awesome-458' => ' fa fa-times-rectangle ', 
 'awesome-459' => ' fa fa-times-rectangle-o ', 
 'awesome-460' => ' fa fa-tint ', 
 'awesome-461' => ' fa fa-toggle-down' , 
 'awesome-462' => ' fa fa-toggle-left' , 
 'awesome-463' => ' fa fa-toggle-off' , 
 'awesome-464' => ' fa fa-toggle-on ', 
 'awesome-465' => ' fa fa-toggle-right' , 
 'awesome-466' => ' fa fa-toggle-up' , 
 'awesome-467' => ' fa fa-trademark ', 
 'awesome-468' => ' fa fa-trash ', 
 'awesome-469' => ' fa fa-trash-o ', 
 'awesome-470' => ' fa fa-tree' , 
 'awesome-471' => ' fa fa-trophy' , 
 'awesome-472' => ' fa fa-truck' , 
 'awesome-473' => ' fa fa-tty ', 
 'awesome-474' => ' fa fa-tv ', 
 'awesome-475' => ' fa fa-umbrella ', 
 'awesome-476' => ' fa fa-universal-access ', 
 'awesome-477' => ' fa fa-university ', 
 'awesome-478' => ' fa fa-unlock ', 
 'awesome-479' => ' fa fa-unlock-alt ', 
 'awesome-480' => ' fa fa-unsorted' , 
 'awesome-481' => ' fa fa-upload' , 
 'awesome-482' => ' fa fa-user ', 
 'awesome-483' => ' fa fa-user-circle' , 
 'awesome-484' => ' fa fa-user-circle-o' , 
 'awesome-485' => ' fa fa-user-o ', 
 'awesome-486' => ' fa fa-user-plus ', 
 'awesome-487' => ' fa fa-user-secret' , 
 'awesome-488' => ' fa fa-user-times ', 
 'awesome-489' => ' fa fa-users ', 
 'awesome-490' => ' fa fa-vcard ', 
 'awesome-491' => ' fa fa-vcard-o ', 
 'awesome-492' => ' fa fa-video-camera ', 
 'awesome-493' => ' fa fa-volume-control-phone ', 
 'awesome-494' => ' fa fa-volume-down ', 
 'awesome-495' => ' fa fa-volume-off ', 
 'awesome-496' => ' fa fa-volume-up' , 
 'awesome-497' => ' fa fa-warning ', 
 'awesome-498' => ' fa fa-wheelchair ', 
 'awesome-499' => ' fa fa-wheelchair-alt ', 
 'awesome-500' => ' fa fa-wifi ', 
 'awesome-501' => ' fa fa-window-close ', 
 'awesome-502' => ' fa fa-window-close-o ', 
 'awesome-503' => ' fa fa-window-maximize' , 
 'awesome-504' => ' fa fa-window-minimize ', 
 'awesome-505' => ' fa fa-window-restore ', 
 'awesome-506' => ' fa fa-wrench ', 
 'awesome-507' => ' fa fa-american-sign-language-interpreting' , 
 'awesome-508' => ' fa fa-asl-interpreting' , 
 'awesome-509' => ' fa fa-assistive-listening-systems ', 
 'awesome-510' => ' fa fa-audio-description ', 
 'awesome-511' => ' fa fa-blind ', 
 'awesome-512' => ' fa fa-braille ', 
 'awesome-513' => ' fa fa-cc ', 
 'awesome-514' => ' fa fa-deaf ', 
 'awesome-515' => ' fa fa-deafness ', 
 'awesome-516' => ' fa fa-hard-of-hearing ', 
 'awesome-517' => ' fa fa-low-vision ', 
 'awesome-518' => ' fa fa-question-circle-o ', 
 'awesome-519' => ' fa fa-sign-language ', 
 'awesome-520' => ' fa fa-signing ', 
 'awesome-521' => ' fa fa-tty ', 
 'awesome-522' => ' fa fa-universal-access ', 
 'awesome-523' => ' fa fa-volume-control-phone ', 
 'awesome-524' => ' fa fa-wheelchair' , 
 'awesome-525' => ' fa fa-wheelchair-alt' , 
 'awesome-526' => ' fa fa-hand-grab-o ', 
 'awesome-527' => ' fa fa-hand-lizard-o ', 
 'awesome-528' => ' fa fa-hand-o-down ', 
 'awesome-529' => ' fa fa-hand-o-left ', 
 'awesome-530' => ' fa fa-hand-o-right ', 
 'awesome-531' => ' fa fa-hand-o-up ', 
 'awesome-532' => ' fa fa-hand-paper-o ', 
 'awesome-533' => ' fa fa-hand-peace-o ', 
 'awesome-534' => ' fa fa-hand-pointer-o ', 
 'awesome-535' => ' fa fa-hand-rock-o' , 
 'awesome-536' => ' fa fa-hand-scissors-o' , 
 'awesome-537' => ' fa fa-hand-spock-o' , 
 'awesome-538' => ' fa fa-hand-stop-o ', 
 'awesome-539' => ' fa fa-thumbs-down ', 
 'awesome-540' => ' fa fa-thumbs-o-down ', 
 'awesome-541' => ' fa fa-thumbs-o-up' , 
 'awesome-542' => ' fa fa-thumbs-up ', 
 'awesome-543' => ' fa fa-ambulance ', 
 'awesome-544' => ' fa fa-automobile' , 
 'awesome-545' => ' fa fa-bicycle ', 
 'awesome-546' => ' fa fa-bus ', 
 'awesome-547' => ' fa fa-cab' , 
 'awesome-548' => ' fa fa-car' , 
 'awesome-549' => ' fa fa-fighter-jet ', 
 'awesome-550' => ' fa fa-motorcycle' , 
 'awesome-551' => ' fa fa-plane ', 
 'awesome-552' => ' fa fa-rocket' , 
 'awesome-553' => ' fa fa-ship ', 
 'awesome-554' => ' fa fa-space-shuttle ', 
 'awesome-555' => ' fa fa-subway ', 
 'awesome-556' => ' fa fa-taxi' , 
 'awesome-557' => ' fa fa-train ', 
 'awesome-558' => ' fa fa-truck ', 
 'awesome-559' => ' fa fa-wheelchair ', 
 'awesome-560' => ' fa fa-wheelchair-alt ', 
 'awesome-561' => ' fa fa-genderless ', 
 'awesome-562' => ' fa fa-intersex ', 
 'awesome-563' => ' fa fa-mars ', 
 'awesome-564' => ' fa fa-mars-double ', 
 'awesome-565' => ' fa fa-mars-stroke ', 
 'awesome-566' => ' fa fa-mars-stroke-h ', 
 'awesome-567' => ' fa fa-mars-stroke-v ', 
 'awesome-568' => ' fa fa-mercury ', 
 'awesome-569' => ' fa fa-neuter ', 
 'awesome-570' => ' fa fa-transgender ', 
 'awesome-571' => ' fa fa-transgender-alt' , 
 'awesome-572' => ' fa fa-venus ', 
 'awesome-573' => ' fa fa-venus-double ', 
 'awesome-574' => ' fa fa-venus-mars ', 
 'awesome-575' => ' fa fa-file' , 
 'awesome-576' => ' fa fa-file-archive-o ', 
 'awesome-577' => ' fa fa-file-audio-o ', 
 'awesome-578' => ' fa fa-file-code-o ', 
 'awesome-579' => ' fa fa-file-excel-o ', 
 'awesome-580' => ' fa fa-file-image-o ', 
 'awesome-581' => ' fa fa-file-movie-o ', 
 'awesome-582' => ' fa fa-file-o ', 
 'awesome-583' => ' fa fa-file-pdf-o ', 
 'awesome-584' => ' fa fa-file-photo-o ', 
 'awesome-585' => ' fa fa-file-picture-o ', 
 'awesome-586' => ' fa fa-file-powerpoint-o ', 
 'awesome-587' => ' fa fa-file-sound-o ', 
 'awesome-588' => ' fa fa-file-text ', 
 'awesome-589' => ' fa fa-file-text-o ', 
 'awesome-590' => ' fa fa-file-video-o ', 
 'awesome-591' => ' fa fa-file-word-o ', 
 'awesome-592' => ' fa fa-file-zip-o ', 
 'awesome-593' => ' fa fa-info-circle fa-lg fa-li ', 
 'awesome-594' => ' fa fa-circle-o-notch ', 
 'awesome-595' => ' fa fa-cog ', 
 'awesome-596' => ' fa fa-gear ', 
 'awesome-597' => ' fa fa-refresh', 
 'awesome-598' => ' fa fa-spinner ', 
 'awesome-599' => ' fa fa-check-square' , 
 'awesome-600' => ' fa fa-check-square-o ', 
 'awesome-601' => ' fa fa-circle ', 
 'awesome-602' => ' fa fa-circle-o ', 
 'awesome-603' => ' fa fa-dot-circle-o' , 
 'awesome-604' => ' fa fa-minus-square ', 
 'awesome-605' => ' fa fa-minus-square-o ', 
 'awesome-606' => ' fa fa-plus-square ', 
 'awesome-607' => ' fa fa-plus-square-o' , 
 'awesome-608' => ' fa fa-square' , 
 'awesome-609' => ' fa fa-square-o ', 
 'awesome-610' => ' fa fa-cc-amex ', 
 'awesome-611' => ' fa fa-cc-diners-club' , 
 'awesome-612' => ' fa fa-cc-discover' , 
 'awesome-613' => ' fa fa-cc-jcb' , 
 'awesome-614' => ' fa fa-cc-mastercard' , 
 'awesome-615' => ' fa fa-cc-paypal' , 
 'awesome-616' => ' fa fa-cc-stripe' , 
 'awesome-617' => ' fa fa-cc-visa' , 
 'awesome-618' => ' fa fa-credit-card' , 
 'awesome-619' => ' fa fa-credit-card-alt' , 
 'awesome-620' => ' fa fa-google-wallet' , 
 'awesome-621' => ' fa fa-paypal' , 
 'awesome-622' => ' fa fa-area-chart ', 
 'awesome-623' => ' fa fa-bar-chart ', 
 'awesome-624' => ' fa fa-bar-chart-o ', 
 'awesome-625' => ' fa fa-line-chart ', 
 'awesome-626' => ' fa fa-pie-chart ', 
 'awesome-627' => ' fa fa-bitcoin' , 
 'awesome-628' => ' fa fa-btc ', 
 'awesome-629' => ' fa fa-cny ', 
 'awesome-630' => ' fa fa-dollar ', 
 'awesome-631' => ' fa fa-eur ', 
 'awesome-632' => ' fa fa-euro ', 
 'awesome-633' => ' fa fa-gbp ', 
 'awesome-634' => ' fa fa-gg ', 
 'awesome-635' => ' fa fa-gg-circle' , 
 'awesome-636' => ' fa fa-ils ', 
 'awesome-637' => ' fa fa-inr ', 
 'awesome-638' => ' fa fa-jpy ', 
 'awesome-639' => ' fa fa-krw ', 
 'awesome-640' => ' fa fa-money ', 
 'awesome-641' => ' fa fa-rmb ', 
 'awesome-642' => ' fa fa-rouble ', 
 'awesome-643' => ' fa fa-rub ', 
 'awesome-644' => ' fa fa-ruble ', 
 'awesome-645' => ' fa fa-rupee ', 
 'awesome-646' => ' fa fa-shekel ', 
 'awesome-647' => ' fa fa-sheqel ', 
 'awesome-648' => ' fa fa-try ', 
 'awesome-649' => ' fa fa-turkish-lira ', 
 'awesome-650' => ' fa fa-usd ', 
 'awesome-651' => ' fa fa-won ', 
 'awesome-652' => ' fa fa-yen ', 
 'awesome-653' => ' fa fa-align-center ', 
 'awesome-654' => ' fa fa-align-justify ', 
 'awesome-655' => ' fa fa-align-left ', 
 'awesome-656' => ' fa fa-align-right' , 
 'awesome-657' => ' fa fa-bold ', 
 'awesome-658' => ' fa fa-chain' , 
 'awesome-659' => ' fa fa-chain-broken' , 
 'awesome-660' => ' fa fa-clipboard ', 
 'awesome-661' => ' fa fa-columns ', 
 'awesome-662' => ' fa fa-copy ', 
 'awesome-663' => ' fa fa-cut ', 
 'awesome-664' => ' fa fa-dedent' , 
 'awesome-665' => ' fa fa-eraser ', 
 'awesome-666' => ' fa fa-file ', 
 'awesome-667' => ' fa fa-file-o ', 
 'awesome-668' => ' fa fa-file-text ', 
 'awesome-669' => ' fa fa-file-text-o ', 
 'awesome-670' => ' fa fa-files-o ', 
 'awesome-671' => ' fa fa-floppy-o ', 
 'awesome-672' => ' fa fa-font ', 
 'awesome-673' => ' fa fa-header' , 
 'awesome-674' => ' fa fa-indent ', 
 'awesome-675' => ' fa fa-italic' , 
 'awesome-676' => ' fa fa-link ', 
 'awesome-677' => ' fa fa-list ', 
 'awesome-678' => ' fa fa-list-alt ', 
 'awesome-679' => ' fa fa-list-ol ', 
 'awesome-680' => ' fa fa-list-ul ', 
 'awesome-681' => ' fa fa-outdent ', 
 'awesome-682' => ' fa fa-paperclip ', 
 'awesome-683' => ' fa fa-paragraph ', 
 'awesome-684' => ' fa fa-paste ', 
 'awesome-685' => ' fa fa-repeat' , 
 'awesome-686' => ' fa fa-rotate-left ', 
 'awesome-687' => ' fa fa-rotate-right ', 
 'awesome-688' => ' fa fa-save ', 
 'awesome-689' => ' fa fa-scissors ', 
 'awesome-690' => ' fa fa-strikethrough ', 
 'awesome-691' => ' fa fa-subscript ', 
 'awesome-692' => ' fa fa-superscript ', 
 'awesome-693' => ' fa fa-table' , 
 'awesome-694' => ' fa fa-text-height ',
 'awesome-695' => ' fa fa-text-width ',
 'awesome-696' => ' fa fa-th ',
 'awesome-697' => ' fa fa-th-large ',
 'awesome-698' => ' fa fa-th-list ',
 'awesome-699' => ' fa fa-underline ',
 'awesome-700' => ' fa fa-undo ',
 'awesome-701' => ' fa fa-unlink ',
 'awesome-702' => ' fa fa-angle-double-down ',
 'awesome-703' => ' fa fa-angle-double-left ',
 'awesome-704' => ' fa fa-angle-double-right ',
 'awesome-705' => ' fa fa-angle-double-up ',
 'awesome-706' => ' fa fa-angle-down ',
 'awesome-707' => ' fa fa-angle-left ',
 'awesome-708' => ' fa fa-angle-right ',
 'awesome-709' => ' fa fa-angle-up ',
 'awesome-710' => ' fa fa-arrow-circle-down ',
 'awesome-711' => ' fa fa-arrow-circle-left ',
 'awesome-712' => ' fa fa-arrow-circle-o-down ',
 'awesome-713' => ' fa fa-arrow-circle-o-left ',
 'awesome-714' => ' fa fa-arrow-circle-o-right ',
 'awesome-715' => ' fa fa-arrow-circle-o-up ',
 'awesome-716' => ' fa fa-arrow-circle-right ',
 'awesome-717' => ' fa fa-arrow-circle-up ',
 'awesome-718' => ' fa fa-arrow-down ',
 'awesome-719' => ' fa fa-arrow-left ',
 'awesome-720' => ' fa fa-arrow-right ',
 'awesome-721' => ' fa fa-arrow-up ',
 'awesome-722' => ' fa fa-arrows ',
 'awesome-723' => ' fa fa-arrows-alt ',
 'awesome-724' => ' fa fa-arrows-h ',
 'awesome-725' => ' fa fa-arrows-v ',
 'awesome-726' => ' fa fa-caret-down ',
 'awesome-727' => ' fa fa-caret-left ',
 'awesome-728' => ' fa fa-caret-right ',
 'awesome-729' => ' fa fa-caret-square-o-down ',
 'awesome-730' => ' fa fa-caret-square-o-left ',
 'awesome-731' => ' fa fa-caret-square-o-right ',
 'awesome-732' => ' fa fa-caret-square-o-up ',
 'awesome-733' => ' fa fa-caret-up ',
 'awesome-734' => ' fa fa-chevron-circle-down ',
 'awesome-735' => ' fa fa-chevron-circle-left ',
 'awesome-736' => ' fa fa-chevron-circle-right ',
 'awesome-737' => ' fa fa-chevron-circle-up ',
 'awesome-738' => ' fa fa-chevron-down ',
 'awesome-739' => ' fa fa-chevron-left ',
 'awesome-740' => ' fa fa-chevron-right ',
 'awesome-741' => ' fa fa-chevron-up ',
 'awesome-742' => ' fa fa-exchange ',
 'awesome-743' => ' fa fa-hand-o-down ',
 'awesome-744' => ' fa fa-hand-o-left ',
 'awesome-745' => ' fa fa-hand-o-right ',
 'awesome-746' => ' fa fa-hand-o-up ',
 'awesome-747' => ' fa fa-long-arrow-down ',
 'awesome-748' => ' fa fa-long-arrow-left ',
 'awesome-749' => ' fa fa-long-arrow-right ',
 'awesome-750' => ' fa fa-long-arrow-up ',
 'awesome-751' => ' fa fa-toggle-down ',
 'awesome-752' => ' fa fa-toggle-left ',
 'awesome-753' => ' fa fa-toggle-right ',
 'awesome-754' => ' fa fa-toggle-up ',
 'awesome-755' => ' fa fa-arrows-alt ',
 'awesome-756' => ' fa fa-backward ',
 'awesome-757' => ' fa fa-compress ',
 'awesome-758' => ' fa fa-eject ',
 'awesome-759' => ' fa fa-expand ',
 'awesome-760' => ' fa fa-fast-backward ',
 'awesome-761' => ' fa fa-fast-forward ',
 'awesome-762' => ' fa fa-forward ',
 'awesome-763' => ' fa fa-pause ',
 'awesome-764' => ' fa fa-pause-circle ',
 'awesome-765' => ' fa fa-pause-circle-o ',
 'awesome-766' => ' fa fa-play ',
 'awesome-767' => ' fa fa-play-circle ',
 'awesome-768' => ' fa fa-play-circle-o ',
 'awesome-769' => ' fa fa-random ',
 'awesome-770' => ' fa fa-step-backward ',
 'awesome-771' => ' fa fa-step-forward ',
 'awesome-772' => ' fa fa-stop ',
 'awesome-773' => ' fa fa-stop-circle ',
 'awesome-774' => ' fa fa-stop-circle-o ',
 'awesome-775' => ' fa fa-youtube-play ',
 'awesome-776' => ' fa fa-500px ',
 'awesome-777' => ' fa fa-adn ',
 'awesome-778' => ' fa fa-amazon ',
 'awesome-779' => ' fa fa-android ',
 'awesome-780' => ' fa fa-angellist ',
 'awesome-781' => ' fa fa-apple ',
 'awesome-782' => ' fa fa-bandcamp ',
 'awesome-783' => ' fa fa-behance ',
 'awesome-784' => ' fa fa-behance-square ',
 'awesome-785' => ' fa fa-bitbucket ',
 'awesome-786' => ' fa fa-bitbucket-square ',
 'awesome-787' => ' fa fa-bitcoin ',
 'awesome-788' => ' fa fa-black-tie ',
 'awesome-789' => ' fa fa-bluetooth ',
 'awesome-790' => ' fa fa-bluetooth-b ',
 'awesome-791' => ' fa fa-btc ',
 'awesome-792' => ' fa fa-buysellads ',
 'awesome-793' => ' fa fa-cc-amex ',
 'awesome-794' => ' fa fa-cc-diners-club ',
 'awesome-795' => ' fa fa-cc-discover ',
 'awesome-796' => ' fa fa-cc-jcb ',
 'awesome-797' => ' fa fa-cc-mastercard ',
 'awesome-798' => ' fa fa-cc-paypal ',
 'awesome-799' => ' fa fa-cc-stripe ',
 'awesome-800' => ' fa fa-cc-visa ',
 'awesome-801' => ' fa fa-chrome ',
 'awesome-802' => ' fa fa-codepen ',
 'awesome-803' => ' fa fa-codiepie ',
 'awesome-804' => ' fa fa-connectdevelop ',
 'awesome-805' => ' fa fa-contao ',
 'awesome-806' => ' fa fa-css3 ',
 'awesome-807' => ' fa fa-dashcube ',
 'awesome-808' => ' fa fa-delicious ',
 'awesome-809' => ' fa fa-deviantart ',
 'awesome-810' => ' fa fa-digg ',
 'awesome-811' => ' fa fa-dribbble ',
 'awesome-812' => ' fa fa-dropbox ',
 'awesome-813' => ' fa fa-drupal ',
 'awesome-814' => ' fa fa-edge ',
 'awesome-815' => ' fa fa-eercast ',
 'awesome-816' => ' fa fa-empire ',
 'awesome-817' => ' fa fa-envira ',
 'awesome-818' => ' fa fa-etsy ',
 'awesome-819' => ' fa fa-expeditedssl ',
 'awesome-820' => ' fa fa-fa ',
 'awesome-821' => ' fa fa-facebook ',
 'awesome-822' => ' fa fa-facebook-f ',
 'awesome-823' => ' fa fa-facebook-official ',
 'awesome-824' => ' fa fa-facebook-square ',
 'awesome-825' => ' fa fa-firefox ',
 'awesome-826' => ' fa fa-first-order ',
 'awesome-827' => ' fa fa-flickr ',
 'awesome-828' => ' fa fa-font-awesome ',
 'awesome-829' => ' fa fa-fonticons ',
 'awesome-830' => ' fa fa-fort-awesome ',
 'awesome-831' => ' fa fa-forumbee ',
 'awesome-832' => ' fa fa-foursquare ',
 'awesome-833' => ' fa fa-free-code-camp ',
 'awesome-834' => ' fa fa-ge ',
 'awesome-835' => ' fa fa-get-pocket ',
 'awesome-836' => ' fa fa-gg ',
 'awesome-837' => ' fa fa-gg-circle ',
 'awesome-838' => ' fa fa-git ',
 'awesome-839' => ' fa fa-git-square ',
 'awesome-840' => ' fa fa-github ',
 'awesome-841' => ' fa fa-github-alt ',
 'awesome-842' => ' fa fa-github-square ',
 'awesome-843' => ' fa fa-gitlab ',
 'awesome-844' => ' fa fa-gittip ',
 'awesome-845' => ' fa fa-glide ',
 'awesome-846' => ' fa fa-glide-g ',
 'awesome-847' => ' fa fa-google ',
 'awesome-848' => ' fa fa-google-plus ',
 'awesome-849' => ' fa fa-google-plus-circle ',
 'awesome-850' => ' fa fa-google-plus-official ',
 'awesome-851' => ' fa fa-google-plus-square ',
 'awesome-852' => ' fa fa-google-wallet ',
 'awesome-853' => ' fa fa-gratipay ',
 'awesome-854' => ' fa fa-grav ',
 'awesome-855' => ' fa fa-hacker-news ',
 'awesome-856' => ' fa fa-houzz ',
 'awesome-857' => ' fa fa-html5 ',
 'awesome-858' => ' fa fa-imdb ',
 'awesome-859' => ' fa fa-instagram ',
 'awesome-860' => ' fa fa-internet-explorer ',
 'awesome-861' => ' fa fa-ioxhost ',
 'awesome-862' => ' fa fa-joomla ',
 'awesome-863' => ' fa fa-jsfiddle ',
 'awesome-864' => ' fa fa-lastfm ',
 'awesome-865' => ' fa fa-lastfm-square ',
 'awesome-866' => ' fa fa-leanpub ',
 'awesome-867' => ' fa fa-linkedin ',
 'awesome-868' => ' fa fa-linkedin-square ',
 'awesome-869' => ' fa fa-linode ',
 'awesome-870' => ' fa fa-linux ',
 'awesome-871' => ' fa fa-maxcdn ',
 'awesome-872' => ' fa fa-meanpath ',
 'awesome-873' => ' fa fa-medium ',
 'awesome-874' => ' fa fa-meetup ',
 'awesome-875' => ' fa fa-mixcloud ',
 'awesome-876' => ' fa fa-modx ',
 'awesome-877' => ' fa fa-odnoklassniki ',
 'awesome-878' => ' fa fa-odnoklassniki-square ',
 'awesome-879' => ' fa fa-opencart ',
 'awesome-880' => ' fa fa-openid ',
 'awesome-881' => ' fa fa-opera ',
 'awesome-882' => ' fa fa-optin-monster ',
 'awesome-883' => ' fa fa-pagelines ',
 'awesome-884' => ' fa fa-paypal ',
 'awesome-885' => ' fa fa-pied-piper ',
 'awesome-886' => ' fa fa-pied-piper-alt ',
 'awesome-887' => ' fa fa-pied-piper-pp ',
 'awesome-888' => ' fa fa-pinterest ',
 'awesome-889' => ' fa fa-pinterest-p ',
 'awesome-890' => ' fa fa-pinterest-square ',
 'awesome-891' => ' fa fa-product-hunt ',
 'awesome-892' => ' fa fa-qq ',
 'awesome-893' => ' fa fa-quora ',
 'awesome-894' => ' fa fa-ra ',
 'awesome-895' => ' fa fa-ravelry ',
 'awesome-896' => ' fa fa-rebel ',
 'awesome-897' => ' fa fa-reddit ',
 'awesome-898' => ' fa fa-reddit-alien ',
 'awesome-899' => ' fa fa-reddit-square ',
 'awesome-900' => ' fa fa-renren ',
 'awesome-901' => ' fa fa-resistance ',
 'awesome-902' => ' fa fa-safari ',
 'awesome-903' => ' fa fa-scribd ',
 'awesome-904' => ' fa fa-sellsy ',
 'awesome-905' => ' fa fa-share-alt ',
 'awesome-906' => ' fa fa-share-alt-square ',
 'awesome-907' => ' fa fa-shirtsinbulk ',
 'awesome-908' => ' fa fa-simplybuilt ',
 'awesome-909' => ' fa fa-skyatlas ',
 'awesome-910' => ' fa fa-skype ',
 'awesome-911' => ' fa fa-slack ',
 'awesome-912' => ' fa fa-slideshare ',
 'awesome-913' => ' fa fa-snapchat ',
 'awesome-914' => ' fa fa-snapchat-ghost ',
 'awesome-915' => ' fa fa-snapchat-square ',
 'awesome-916' => ' fa fa-soundcloud ',
 'awesome-917' => ' fa fa-spotify ',
 'awesome-918' => ' fa fa-stack-exchange ',
 'awesome-919' => ' fa fa-stack-overflow ',
 'awesome-920' => ' fa fa-steam ',
 'awesome-921' => ' fa fa-steam-square ',
 'awesome-922' => ' fa fa-stumbleupon ',
 'awesome-923' => ' fa fa-stumbleupon-circle ',
 'awesome-924' => ' fa fa-superpowers ',
 'awesome-925' => ' fa fa-telegram ',
 'awesome-926' => ' fa fa-tencent-weibo ',
 'awesome-927' => ' fa fa-themeisle ',
 'awesome-928' => ' fa fa-trello ',
 'awesome-929' => ' fa fa-tripadvisor ',
 'awesome-930' => ' fa fa-tumblr ',
 'awesome-931' => ' fa fa-tumblr-square ',
 'awesome-932' => ' fa fa-twitch ',
 'awesome-933' => ' fa fa-twitter ',
 'awesome-934' => ' fa fa-twitter-square ',
 'awesome-935' => ' fa fa-usb ',
 'awesome-936' => ' fa fa-viacoin ',
 'awesome-937' => ' fa fa-viadeo ',
 'awesome-938' => ' fa fa-viadeo-square ',
 'awesome-939' => ' fa fa-vimeo ',
 'awesome-940' => ' fa fa-vimeo-square ',
 'awesome-941' => ' fa fa-vine ',
 'awesome-942' => ' fa fa-vk ',
 'awesome-943' => ' fa fa-wechat ',
 'awesome-944' => ' fa fa-weibo ',
 'awesome-945' => ' fa fa-weixin ',
 'awesome-946' => ' fa fa-whatsapp ',
 'awesome-947' => ' fa fa-wikipedia-w ',
 'awesome-948' => ' fa fa-windows ',
 'awesome-949' => ' fa fa-wordpress ',
 'awesome-950' => ' fa fa-wpbeginner ',
 'awesome-951' => ' fa fa-wpexplorer ',
 'awesome-952' => ' fa fa-wpforms ',
 'awesome-953' => ' fa fa-xing ',
 'awesome-954' => ' fa fa-xing-square ',
 'awesome-955' => ' fa fa-y-combinator ',
 'awesome-956' => ' fa fa-y-combinator-square ',
 'awesome-957' => ' fa fa-yahoo ',
 'awesome-958' => ' fa fa-yc ',
 'awesome-959' => ' fa fa-yc-square ',
 'awesome-960' => ' fa fa-yelp ',
 'awesome-961' => ' fa fa-yoast ',
 'awesome-962' => ' fa fa-youtube ',
 'awesome-963' => ' fa fa-youtube-play ',
 'awesome-964' => ' fa fa-youtube-square ',
 'awesome-965' => ' fa fa-warning ',
 'awesome-966' => ' fa fa-ambulance ',
 'awesome-967' => ' fa fa-h-square ',
 'awesome-968' => ' fa fa-heart ',
 'awesome-969' => ' fa fa-heart-o ',
 'awesome-970' => ' fa fa-heartbeat ',
 'awesome-971' => ' fa fa-hospital-o ',
 'awesome-972' => ' fa fa-medkit ',
 'awesome-973' => ' fa fa-plus-square ',
 'awesome-974' => ' fa fa-stethoscope ',
 'awesome-975' => ' fa fa-user-md ',
 'awesome-976' => ' fa fa-wheelchair ',
 'awesome-977' => ' fa fa-wheelchair-alt ',
        );

        $icons = apply_filters( "megamenu_awesome", $icons );

        ksort( $icons );

        return $icons;
    }
/**********************************************************/
}

endif;